@@ -18,6 +18,7 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Cancel" : "Odustani",
     "Actions" : "Radnje",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
     "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
@@ -44,8 +45,13 @@ OC.L10N.register(
     "Attendees" : "Sudionici",
     "Repeat" : "Ponovi",
     "never" : "nikad",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "Create" : "Kreiraj",
     "Personal" : "Osobno",
+    "Edit event" : "Izmjeni događaj",
     "Close" : "Zatvori",
+    "Title" : "Naslov",
     "Daily" : "Dnevno",
     "Weekly" : "Sedmično",
     "second" : "drugi",
