@@ -11,6 +11,7 @@ OC.L10N.register(
     "Description:" : "Descripcion :",
     "Date:" : "Data :",
     "Where:" : "Ont :",
+    "Location:" : "Localizacion :",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -49,20 +50,25 @@ OC.L10N.register(
     "Deleting share link …" : "Supression del ligam de partatge …",
     "can edit" : "pòt modificar",
     "Save" : "Salvar",
+    "View" : "Veire",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
     "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
     "Automatic" : "Automatic",
-    "or" : "o",
     "Navigation" : "Navegacion",
     "Views" : "Vistas",
     "Day view" : "Mostrar un jorn",
     "Week view" : "Monstrar una setmana",
     "Month view" : "Monstrar un mes",
     "Actions" : "Accions",
+    "or" : "o",
+    "General" : "Generals",
     "Show weekends" : "Monstrar las dimenjadas",
+    "Editing" : "Edicion",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
     "0 minutes" : "0 minuta",
+    "Update" : "Metre a jorn",
     "Location" : "Emplaçament",
     "Description" : "Descripcion",
     "Visibility" : "Visibilitat",
@@ -76,35 +82,31 @@ OC.L10N.register(
     "Friday" : "Divendres",
     "Saturday" : "Dissabte",
     "Sunday" : "Dimenge",
-    "Update" : "Metre a jorn",
     "Your name" : "Vòstre nom",
     "Your email address" : "Vòstra adreça electronica",
-    "Create a new conversation" : "Crear una conversacion novèla",
     "Select conversation" : "Seleccionar una conversacion",
-    "Reminder" : "Recòrd",
+    "on" : "lo",
+    "at" : "a",
     "Notification" : "Notificacion",
     "Email" : "Adreça corrièl",
     "Audio notification" : "Notificacion àudio",
     "Other notification" : "Autras notificacions",
     "Edit time" : "Modificar l’ora",
     "Remove reminder" : "Suprimir lo rapèl",
-    "on" : "lo",
-    "at" : "a",
-    "+ Add reminder" : "+ Apondre un rapèl",
-    "_second_::_seconds_" : ["segonda","segondas"],
-    "_minute_::_minutes_" : ["minuta","minutas"],
-    "_hour_::_hours_" : ["ora","oras"],
-    "_day_::_days_" : ["jorn","jorns"],
-    "_week_::_weeks_" : ["setmana","setmanas"],
-    "Delete file" : "Suprimir fichièr",
+    "seconds" : "segondas",
+    "minutes" : "minutas",
+    "hours" : "oras",
+    "days" : "jorns",
+    "weeks" : "setmanas",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
+    "Delete file" : "Suprimir fichièr",
     "Available" : "Disponible",
+    "Out of office" : "Fòra del burèu",
+    "Room name" : "Nom de la sala",
     "Free" : "Liure",
     "Busy (tentative)" : "Ocupat (provisòri)",
     "Busy" : "Ocupat",
-    "Out of office" : "Fòra del burèu",
     "Unknown" : "Desconegut",
-    "Room name" : "Nom de la sala",
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
@@ -113,37 +115,43 @@ OC.L10N.register(
     "Remove color" : "Suprimir la color",
     "Event title" : "Títol de l’eveniment",
     "From" : "De",
-    "All day" : "Tota la jornada",
     "Repeat" : "Repetir",
+    "_time_::_times_" : ["còp","còps"],
     "never" : "pas jamai",
     "after" : "aprèp",
-    "_time_::_times_" : ["còp","còps"],
     "first" : "primièr",
-    "third" : "tresen",
-    "fourth" : "quatren",
-    "fifth" : "cinquen",
-    "last" : "darrièr",
+    "_day_::_days_" : ["jorn","jorns"],
+    "_week_::_weeks_" : ["setmana","setmanas"],
     "_month_::_months_" : ["mes","mese"],
     "_year_::_years_" : ["annada","annadas"],
     "weekday" : "dimenjada",
     "weekend day" : "jorn de la setmana",
-    "Suggestions" : "Suggestions",
     "Add resource" : "Apondre ressorsa",
     "available" : "disponible",
     "unavailable" : "indisponible",
     "Room type" : "Tipe de sala",
     "Any" : "Quina que siá",
-    "Pick a time" : "Causir una ora",
-    "Pick a date" : "Causir una data",
+    "Remove participant" : "Tirar participant",
+    "Yes" : "Òc",
+    "No" : "Non",
+    "Create" : "Crear",
     "from {formattedDate}" : "a partir de {formattedDate}",
     "to {formattedDate}" : "cap a {formattedDate}",
+    "Pick a time" : "Causir una ora",
+    "Pick a date" : "Causir una data",
     "Type to search time zone" : "Picar per cercar un fus orari",
     "Global" : "Global",
     "Subscribe" : "S'abonar",
     "Personal" : "Personal",
-    "Details" : "Detalhs",
-    "Close" : "Tampar",
+    "Edit event" : "Editar un eveniment",
+    "All day" : "Tota la jornada",
     "Untitled event" : "Eveniment sens nom",
+    "Close" : "Tampar",
+    "Selected" : "Seleccionat",
+    "Title" : "Títol",
+    "30 min" : "30 min",
+    "Participants" : "Participants",
+    "Submit" : "Transmetre",
     "Anniversary" : "Anniversari",
     "Appointment" : "Rendetz-vos",
     "Business" : "Afar",
@@ -161,6 +169,11 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
+    "second" : "segonda",
+    "third" : "tresen",
+    "fourth" : "quatren",
+    "fifth" : "cinquen",
+    "last" : "darrièr",
     "Untitled task" : "Prètzfach sens nom",
     "Other" : "Autre",
     "Add a location" : "Apondre un lòc",
@@ -170,12 +183,6 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
-    "User not found" : "Utilizaire pas trobat",
-    "Create a new event" : "Crear un eveniment novèl",
-    "[Today]" : "[Uèi]",
-    "[Tomorrow]" : "[Deman]",
-    "[Yesterday]" : "[Ièr]",
-    "[Last] dddd" : "dddd [passat]",
-    "Add a description" : "Apondre una descripcion"
+    "User not found" : "Utilizaire pas trobat"
 },
 "nplurals=2; plural=(n > 1);");
